Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Transfer Family.

Actions, resources, and condition keys for AWS Transfer Family - Service Authorization Reference

# Actions, resources, and condition keys for AWS Transfer Family

AWS Transfer Family (service prefix: `transfer` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Transfer Family
- Resource types defined by AWS Transfer Family
- Condition keys for AWS Transfer Family

## Actions defined by AWS Transfer Family

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateAccess | Grants permission to add an access associated with a server | Write | server* |  | iam:PassRole
CreateAgreement | Grants permission to add an agreement associated with a server | Write | server* |  | iam:PassRole
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateConnector | Grants permission to create a connector | Write |  | aws:TagKeys aws:RequestTag/${TagKey} | iam:PassRole
CreateProfile | Grants permission to create a profile | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreateServer | Grants permission to create a server | Write |  | aws:TagKeys aws:RequestTag/${TagKey} | iam:PassRole
CreateUser | Grants permission to add a user associated with a server | Write | server* |  | iam:PassRole
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateWorkflow | Grants permission to create a workflow | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
DeleteAccess | Grants permission to delete access | Write | server* |  |
DeleteAgreement | Grants permission to delete agreement | Write | agreement* |  |
DeleteCertificate | Grants permission to delete certificate | Write | certificate* |  |
DeleteConnector | Grants permission to delete connector | Write | connector* |  |
DeleteHostKey | Grants permission to delete a host key associated with a server | Write | host-key* |  |
DeleteProfile | Grants permission to delete profile | Write | profile* |  |
DeleteServer | Grants permission to delete a server | Write | server* |  |
DeleteSshPublicKey | Grants permission to delete an SSH public key from a user | Write | user* |  |
DeleteUser | Grants permission to delete a user associated with a server | Write | user* |  |
DeleteWorkflow | Grants permission to delete a workflow | Write | workflow* |  |
DescribeAccess | Grants permission to describe an access assigned to a server | Read | server* |  |
DescribeAgreement | Grants permission to describe an agreement assigned to a server | Read | agreement* |  |
DescribeCertificate | Grants permission to describe a certificate | Read | certificate* |  |
DescribeConnector | Grants permission to describe a connector | Read | connector* |  |
DescribeExecution | Grants permission to describe an execution associated with a workflow | Read | workflow* |  |
DescribeHostKey | Grants permission to describe a host key associated with a server | Read | host-key* |  |
DescribeProfile | Grants permission to describe a profile | Read | profile* |  |
DescribeSecurityPolicy | Grants permission to describe a security policy | Read |  |  |
DescribeServer | Grants permission to describe a server | Read | server* |  |
DescribeUser | Grants permission to describe a user associated with a server | Read | user* |  |
DescribeWorkflow | Grants permission to describe a workflow | Read | workflow* |  |
ImportCertificate | Grants permission to add a certificate | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
ImportHostKey | Grants permission to add a host key to a server | Write | server* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
ImportSshPublicKey | Grants permission to add an SSH public key to a user | Write | user* |  |
ListAccesses | Grants permission to list accesses | Read | server* |  |
ListAgreements | Grants permission to list agreements | Read | server* |  |
ListCertificates | Grants permission to list certificates | Read |  |  |
ListConnectors | Grants permission to list connectors | Read |  |  |
ListExecutions | Grants permission to list executions associated with a workflow | Read | workflow* |  |
ListHostKeys | Grants permission to list host keys associated with a server | Read | server* |  |
ListProfiles | Grants permission to list profiles | Read |  |  |
ListSecurityPolicies | Grants permission to list security policies | List |  |  |
ListServers | Grants permission to list servers | List |  |  |
ListTagsForResource | Grants permission to list tags for an AWS Transfer Family resource | Read | agreement |  |
certificate |  |
connector |  |
host-key |  |
profile |  |
server |  |
user |  |
workflow |  |
ListUsers | Grants permission to list users associated with a server | List | server* |  |
ListWorkflows | Grants permission to list workflows | List |  |  |
SendWorkflowStepState | Grants permission to send a callback for asynchronous custom steps | Write | workflow* |  |
StartFileTransfer | Grants permission to initiate a connector file transfer | Write | connector* |  |
StartServer | Grants permission to start a server | Write | server* |  |
StopServer | Grants permission to stop a server | Write | server* |  |
TagResource | Grants permission to tag an AWS Transfer Family resource | Tagging | agreement |  |
certificate |  |
connector |  |
host-key |  |
profile |  |
server |  |
user |  |
workflow |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
TestIdentityProvider | Grants permission to test a server's custom identity provider | Read | user* |  |
UntagResource | Grants permission to untag an AWS Transfer Family resource | Tagging | agreement |  |
certificate |  |
connector |  |
host-key |  |
profile |  |
server |  |
user |  |
workflow |  |
| aws:TagKeys |
UpdateAccess | Grants permission to update access | Write |  |  | iam:PassRole
UpdateAgreement | Grants permission to update an agreement | Write | agreement* |  | iam:PassRole
UpdateCertificate | Grants permission to update a certificate | Write | certificate* |  |
UpdateConnector | Grants permission to update a connector | Write | connector* |  | iam:PassRole
UpdateHostKey | Grants permission to update a host key | Write | host-key* |  |
UpdateProfile | Grants permission to update a profile | Write | profile* |  |
UpdateServer | Grants permission to update the configuration of a server | Write | server* |  | iam:PassRole
UpdateUser | Grants permission to update the configuration of a user | Write | user* |  | iam:PassRole

## Resource types defined by AWS Transfer Family

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
user | `arn:$ { Partition}:transfer:$ { Region}:$ { Account}:user/$ { ServerId}/$ { UserName}` | aws:ResourceTag/${TagKey}
server | `arn:$ { Partition}:transfer:$ { Region}:$ { Account}:server/$ { ServerId}` | aws:ResourceTag/${TagKey}
workflow | `arn:$ { Partition}:transfer:$ { Region}:$ { Account}:workflow/$ { WorkflowId}` | aws:ResourceTag/${TagKey}
certificate | `arn:$ { Partition}:transfer:$ { Region}:$ { Account}:certificate/$ { CertificateId}` | aws:ResourceTag/${TagKey}
connector | `arn:$ { Partition}:transfer:$ { Region}:$ { Account}:connector/$ { ConnectorId}` | aws:ResourceTag/${TagKey}
profile | `arn:$ { Partition}:transfer:$ { Region}:$ { Account}:profile/$ { ProfileId}` | aws:ResourceTag/${TagKey}
agreement | `arn:$ { Partition}:transfer:$ { Region}:$ { Account}:agreement/$ { AgreementId}` | aws:ResourceTag/${TagKey}
host-key | `arn:$ { Partition}:transfer:$ { Region}:$ { Account}:host-key/$ { ServerId}/$ { HostKeyId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Transfer Family

AWS Transfer Family defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.